# GitHub App Permissions
### On this page
  * [Repository Permissions](https://help.sap.com/docs/leanix/ea/github-app-permissions#repository-permissions)
  * [Organization Permissions](https://help.sap.com/docs/leanix/ea/github-app-permissions#organization-permissions)
  * [Webhook Events](https://help.sap.com/docs/leanix/ea/github-app-permissions#webhook-events)


Enable the necessary permissions for the GitHub App and subscribe to webhook events to ensure proper operation.
